==> qiho-center-api-2.3.71-20200312.102159-5-sources.jar: com/qiho/center/api/dto/task/OrderConfirmTaskDetailDto.java <==
package com.qiho.center.api.dto.task;

import java.io.Serializable;
import java.util.Date;

/**
 * Created by weny.cai on 2018/3/28.
 */
public class OrderConfirmTaskDetailDto  implements Serializable {

    private Long id;

    private Long orderConfirmTaskId;

    private String orderId;

    private String postId;

    private Integer lineNum;

    private String failMsg;

    private Date gmtCreate;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getOrderConfirmTaskId() {
        return orderConfirmTaskId;
    }

    public void setOrderConfirmTaskId(Long orderConfirmTaskId) {
        this.orderConfirmTaskId = orderConfirmTaskId;
    }

    public String getOrderId() {
        return orderId;
    }

    public void setOrderId(String orderId) {
        this.orderId = orderId == null ? null : orderId.trim();
    }

    public String getPostId() {
        return postId;
    }

    public void setPostId(String postId) {
        this.postId = postId == null ? null : postId.trim();
    }

    public Integer getLineNum() {
        return lineNum;
    }

    public void setLineNum(Integer lineNum) {
        this.lineNum = lineNum;
    }

    public String getFailMsg() {
        return failMsg;
    }

    public void setFailMsg(String failMsg) {
        this.failMsg = failMsg == null ? null : failMsg.trim();
    }


    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }
}

==> qiho-center-api-2.5.3-sources.jar: com/qiho/center/api/dto/task/OrderConfirmTaskDetailDto.java <==
package com.qiho.center.api.dto.task;

import java.io.Serializable;
import java.util.Date;

/**
 * Created by weny.cai on 2018/3/28.
 */
public class OrderConfirmTaskDetailDto  implements Serializable {

    private Long id;

    private Long orderConfirmTaskId;

    private String orderId;

    private String postId;

    private Integer lineNum;

    private String failMsg;

    private Date gmtCreate;

    /**
     * 商品Id
     */
    private String itemId;

    /**
     * 下单日期
     */
    private String orderDate;

    /**
     * 手机号
     */
    private String mobile;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getOrderConfirmTaskId() {
        return orderConfirmTaskId;
    }

    public void setOrderConfirmTaskId(Long orderConfirmTaskId) {
        this.orderConfirmTaskId = orderConfirmTaskId;
    }

    public String getOrderId() {
        return orderId;
    }

    public void setOrderId(String orderId) {
        this.orderId = orderId == null ? null : orderId.trim();
    }

    public String getPostId() {
        return postId;
    }

    public void setPostId(String postId) {
        this.postId = postId == null ? null : postId.trim();
    }

    public Integer getLineNum() {
        return lineNum;
    }

    public void setLineNum(Integer lineNum) {
        this.lineNum = lineNum;
    }

    public String getFailMsg() {
        return failMsg;
    }

    public void setFailMsg(String failMsg) {
        this.failMsg = failMsg == null ? null : failMsg.trim();
    }


    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public String getItemId() {
        return itemId;
    }

    public void setItemId(String itemId) {
        this.itemId = itemId;
    }

    public String getOrderDate() {
        return orderDate;
    }

    public void setOrderDate(String orderDate) {
        this.orderDate = orderDate;
    }

    public String getMobile() {
        return mobile;
    }

    public void setMobile(String mobile) {
        this.mobile = mobile;
    }
}
